/* ccgo: go/gtk/gtktest.cc
 * 
 * Copyright 2004 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include <arg.hh>
#include <debug.hh>
#include <gtk/gtk.hh>
#include <go/sgf.hh>
#include <gtkmm/main.h>
#include <gconfmm/init.h>
#include <fstream>

using namespace std;

int main(int argc, char * argv[])
{
	arg::Parser p;

	p.add_opt('d', "debug")
		.store(arg::SV(& debug_level))
		.help("setting debug level to NUM", "NUM");

	string sgf_file;
	p.add_opt('f', "sgf-file")
		.store(arg::SV(& sgf_file))
		.help("open FILE as SGF file", "FILE");
	p.add_opt_help();
	p.add_opt_version(string("ccGo ") + VERSION);

	p.parse(argc, argv);

	ccgo::Game * g = 0;
	if (sgf_file.size()) {
		msg(DBG_INFO) << "loading sgf file: " << sgf_file << '\n';
		fstream f(sgf_file.c_str(), ios::in);
		if (f) g = ccgo::load_sgf(f);
		msg(DBG_DEBUG) << "sgf file loaded\n";
	}

	if (! g) for (vector<string>::const_iterator i = p.args().begin(); i != p.args().end(); i ++) {
		const string & s = * i;
		if (s.length() < 4) continue;
		if (s.substr(s.length() - 4) == ".sgf") {
			msg(DBG_INFO) << "loading sgf file: " << string(sgf_file) << "\n";
			fstream f(s.c_str(), ios::in);
			if (f) g = ccgo::load_sgf(f);
			msg(DBG_DEBUG) << "sgf loaded\n";
			break;
		}
	}

	if (! g) {
		g = new ccgo::Game;
		g->set_init(19);
	}
	Gtk::Main m(& argc, & argv);
	Gnome::Conf::init();
	gtk::View v;
	v.set_node(g);
	v.show_all();
	msg(DBG_INFO) << "starting main loop\n";
	Gtk::Main::run(v);
	msg(DBG_INFO) << "main loop ended\n";
	return 0;
}
